==> pypaperless_5.1.0.orig.tar.gz: paperless-api-5.1.0/tests/data/mail.py <==
"""Mail snapshots."""

# mypy: ignore-errors

DATA_MAIL_ACCOUNTS = {
    "count": 1,
    "next": None,
    "previous": None,
    "all": [1],
    "results": [
        {
            "id": 1,
            "name": "Test Account",
            "imap_server": "imap.omega.net",
            "imap_port": 1337,
            "imap_security": 2,
            "username": "omega-weapon",
            "password": "********************",
            "character_set": "UTF-8",
            "is_token": False,
            "owner": 1,
            "user_can_change": True,
        }
    ],
}

DATA_MAIL_RULES = {
    "count": 1,
    "next": None,
    "previous": None,
    "all": [1],
    "results": [
        {
            "id": 1,
            "name": "Test",
            "account": 1,
            "folder": "INBOX",
            "filter_from": None,
            "filter_to": None,
            "filter_subject": None,
            "filter_body": None,
            "filter_attachment_filename_include": None,
            "filter_attachment_filename_exclude": None,
            "maximum_age": 3,
            "action": 3,
            "action_parameter": None,
            "assign_title_from": 1,
            "assign_tags": [],
            "assign_correspondent_from": 1,
            "assign_correspondent": None,
            "assign_document_type": None,
            "assign_owner_from_rule": True,
            "order": 1,
            "attachment_type": 1,
            "consumption_scope": 1,
            "owner": 1,
            "user_can_change": True,
        }
    ],
}

==> pypaperless_5.2.0.orig.tar.gz: paperless-api-5.2.0/tests/data/mail.py <==
"""Mail snapshots."""

# mypy: ignore-errors

DATA_MAIL_ACCOUNTS = {
    "count": 1,
    "next": None,
    "previous": None,
    "all": [1],
    "results": [
        {
            "id": 1,
            "name": "Test Account",
            "imap_server": "imap.omega.net",
            "imap_port": 1337,
            "imap_security": 2,
            "username": "omega-weapon",
            "password": "********************",
            "character_set": "UTF-8",
            "is_token": False,
            "owner": 1,
            "user_can_change": True,
        }
    ],
}

DATA_MAIL_RULES = {
    "count": 1,
    "next": None,
    "previous": None,
    "all": [1],
    "results": [
        {
            "id": 1,
            "name": "Test",
            "account": 1,
            "folder": "INBOX",
            "filter_from": None,
            "filter_to": None,
            "filter_subject": None,
            "filter_body": None,
            "filter_attachment_filename_include": None,
            "filter_attachment_filename_exclude": None,
            "maximum_age": 3,
            "action": 3,
            "action_parameter": None,
            "assign_title_from": 1,
            "assign_tags": [],
            "assign_correspondent_from": 1,
            "assign_correspondent": None,
            "assign_document_type": None,
            "assign_owner_from_rule": True,
            "order": 1,
            "attachment_type": 1,
            "consumption_scope": 1,
            "owner": 1,
            "user_can_change": True,
        }
    ],
}

DATA_PROCESSED_MAIL = {
    "count": 3,
    "next": None,
    "previous": None,
    "all": [1, 2, 3],
    "results": [
        {
            "id": 1,
            "owner": 1,
            "rule": 1,
            "folder": "INBOX",
            "uid": "abcdef",
            "subject": "Invoice #1",
            "received": "2025-11-16T08:18:25+01:00",
            "processed": "2025-11-16T11:00:17.838202+01:00",
            "status": "SUCCESS",
            "error": None,
        },
        {
            "id": 2,
            "owner": 1,
            "rule": 1,
            "folder": "INBOX",
            "uid": "fedcba",
            "subject": "Invoice #2",
            "received": "2025-11-16T07:56:16+01:00",
            "processed": "2025-11-16T08:00:17.660439+01:00",
            "status": "SUCCESS",
            "error": None,
        },
        {
            "id": 3,
            "owner": 1,
            "rule": 1,
            "folder": "INBOX",
            "uid": "123456",
            "subject": "Invoice #3",
            "received": "2025-11-16T13:54:23+01:00",
            "processed": "2025-11-16T14:00:17.846562+01:00",
            "status": "SUCCESS",
            "error": None,
        },
    ],
}
